module com.fasterxml.jackson.jr.annotationsupport {
    requires com.fasterxml.jackson.core;

    requires com.fasterxml.jackson.jr.ob;

    exports com.fasterxml.jackson.jr.annotationsupport;
}
